function radiation = getRadiationPerM2(tiltAngle, orientation)

%----------global values------------------

global from;
global totalLength;
global latitude;
global longlitude;
global cloudiness;
%----------end global values---------------

latitudeNum = str2num(latitude);
longlitudeNum = str2num(longlitude);

%days in the different months of year starting with january. We neglect
%leap year for simplification
month = [31 28 31 30 31 30 31 31 30 31 30 31];


temp = regexp(from, 'T', 'split');
temp1 = temp(1);
temp2 = temp(2);
fromDate = regexp(char(temp1), '-', 'split');
fromClock = regexp(char(temp2), ':', 'split'); 

fromMonth = str2num(char(fromDate(2)));
fromDay = str2num(char(fromDate(3)));
firstWholeHourGMT = str2num(char(fromClock(1)));

clear temp1 temp2; 

    % Calculation of which day of the year the prediction starts
    daynumberStart = sum(month(1:fromMonth-1)) + fromDay;


    %omega is angle in degree between south and the horizontal projection of the sun beam. 
    delta = 15;

    if(firstWholeHourGMT < 12)
        omegaStart = 360-(12-firstWholeHourGMT)*delta+longlitudeNum;

    elseif(firstWholeHourGMT > 12)
        omegaStart = (firstWholeHourGMT-12)*delta + longlitudeNum;

    else
        omegaStart = longlitudeNum;
    end


    omega = [omegaStart:15:omegaStart+15*totalLength];



    %Checking how many hours left of the day to set right daynumber

    hoursLeftOfDay = 24-firstWholeHourGMT; %variable between 1 and 24;
    k = totalLength-24-hoursLeftOfDay;

    if (k>24)
        l = k-24;
        extraDays = [zeros(1,hoursLeftOfDay) ones(1,24) 2*ones(1,24) 3*ones(1,l)];

    
    else
        extraDays = [zeros(1,hoursLeftOfDay) ones(1,24) 2*ones(1,k)];

    end

    clear k l;

%Calculating declination vector
    for k=1:totalLength
        declinationVector(k) = 23.45*sind(360*(284+daynumberStart+extraDays(k))/365);

    end
    
    clear k;

    %Calculating cosTheta1 which is angle divider through atmosphere. Since
    %atmosphere has no tilt beta = 0 

    for k=1:totalLength
        cosAtmosphereAngle(k) =  sind(declinationVector(k))*sind(latitudeNum) +... 
        cosd(declinationVector(k))*cosd(latitudeNum)*cosd(omega(k));
    
    end
        
    %Calculating cosFixedPlaneAngle which is projection angle between fixed normal line of plane and
    %sun beam

    for k=1:totalLength

            cosFixedPlaneAngle(k) = sind(declinationVector(k))*sind(latitudeNum)*cosd(tiltAngle)-...
            sind(declinationVector(k))*cosd(latitudeNum)*sind(tiltAngle)*cosd(orientation)+...
            cosd(declinationVector(k))*cosd(latitudeNum)*cosd(tiltAngle)*cosd(omega(k))+...
            cosd(declinationVector(k))*sind(latitudeNum)*sind(tiltAngle)*cosd(orientation)*cosd(omega(k))+...
            cosd(declinationVector(k))*sind(tiltAngle)*sind(orientation)*sind(omega(k));


    end

            

%------------------Start of Calcualting Radiation per m^2 if clear skies----------------%

    IZero = 1360;  % The solar Constant I_0 = 1360 W/m^2
    
    a=0.15;     %Constants approximated for Oslo
    b=0.14;          
    c=0.1;      
    
    for k=1:totalLength
        %radiation will be set to zero if any of these angles are negative
        if(cosAtmosphereAngle(k) <=0 || cosFixedPlaneAngle(k)<=0 )
    
            valueList(k) = 0;   %radiation
        else
            %radiation and reduction because of cloudiness. Approximated
            %reduction is 9.4 W/m^2%
            valueList(k) =  (IZero*(1-(a/sqrt(cosAtmosphereAngle(k))+((1-a/sqrt(cosAtmosphereAngle(k)))...       
            *(b/(cosAtmosphereAngle(k)+c)))))-(9.4*cloudiness(k)))*cosFixedPlaneAngle(k);           
            
            
            if(valueList(k) <= 0)
            valueList(k) = 0;      %can't have negative radiation
            end    
        end
    end
%------------------End of Calcualting Radiation if clear skies--------------------------%


    radiation = valueList;

end