%% initiating constants

mr = 50; %[kg]
cw = 4184; %[j/(kg celsius)]
g1 = 100; %[w/celsius]
g2 = 500; %[w/celsius]
g3 = 130; %[w/celsius]
mRoomCroom = 1.8e7; %[j/celsius]


%% getting global data
global temperature;
global totalLength;


%% initial linearization points

%states
x1 = 70; %[degrees celsius]
x2 = 750; %[litres]
x4 = 20; % [degrees celsius]

%disturbances
v1 = 70; %[degrees celsius]
v2 = 0; %[litres/s]
v3 = 20; %[degrees celsius] [constant]
v4 = sum(temperature)/totalLength; %[degrees celsius]


%% Finding rest of nominal values
% solving by setting all nonlinear derrivatives to zero and back
% substitution

x3 = x4*(1+(g3/g2)) - (g3/g2)*v4;
u3 = (g2*(x3-x4)) / (cw*(x1-x3));
u2 = u3;
u1 = ((-cw*u2*v1 + cw*x1*(u3+v2) + g1*(x1-v3)))/1000;

%inserting in vectors
xNom = [x1 x2 x3 x4]';
uNom = [u1 u2 u3]';
vNom = [v1 v2 v3 v4]';

%% Obtaining matrix components

a11 = (-1/x2)*(u3+v2+(g1/cw));
a12 = (-1/x2^2)*(((1000*u1)/cw)+(u2*v1)-(x1*u3)-(x1*v2)-(g1/cw)*(x1-v3));
a31 = u3/mr;
a33 = -((u3/mr)+(g2/(mr*cw)));
a34 = g2/(mr*cw);
a43 = g2/(mRoomCroom);
a44 = -((g2+g3)/mRoomCroom);

b11 = 1000/(cw*x2);
b12 = v1/x2;
b13 = -(x1/x2);
b22 = 1;
b23 = -1;
b33 = (x1-x3)/mr;

c11 = u2/x2;
c12 = -(x1/x2);
c13 = g1/(cw*x2);
c22 = -1;
c44 = g3/mRoomCroom;

A = [a11 a12 0 0 ; 0 0 0 0 ; a31 0 a33 a34; 0 0 a43 a44];
B = [b11 b12 b13 ; 0 b22 b23 ; 0 0 b33 ; 0 0 0];
C = [c11 c12 c13 0 ; 0 c22 0 0 ; 0 0 0 0 ; 0 0 0 c44];

temp = -A*xNom-B*uNom-C*vNom;
temp1 = temp(1);
temp2 = temp(2);
temp3 = temp(3);
temp4 = temp(4);

W = [temp1 0 0 0 ; 0 temp2 0 0 ; 0 0 temp3 0 ; 0 0 0 temp4];

clear temp temp1 temp2 temp3 temp4;

D = [B C W];
G = eye(4);
H = zeros(4,11);

%creating discrete model
ts = 900;
model = c2d(ss(A,D,G,H),ts);

%clear D G H;

%Assign types of I/O variables
model=setmpcsignals(model,'MV',[1 2 3],'MD',[4 6 7 8 9 10 11],'UD',[5]);



%Assign names to I/O variables

model.InputName  = {'u1';'u2';'u3';'v1';'v2';'v3';'v4';'v5';'v6';'v7';'v8'};
model.Outputname = {'x1';'x2';'x3';'x4'};


%Define I/O constraints and units
clear InputSpecs Outputspecs;

InputSpecs(1) = struct('Min',0,'Max',10,'RateMin',-Inf,'Ratemax',Inf,'Units','kW');
InputSpecs(2) = struct('Min',0,'Max',0.1,'RateMin',-Inf,'Ratemax',Inf,'Units','liters per second');
InputSpecs(3) = struct('Min',0,'Max',0.1,'RateMin',-Inf,'Ratemax',Inf,'Units','liters per second');

Outputspecs(1) = struct('Min',70,'Max',100,'Units','degrees celsius');
Outputspecs(2) = struct('Min',0,'Max',1000,'Units','kg');
Outputspecs(3) = struct('Min',0,'Max',100,'Units','degrees celsius');
Outputspecs(4) = struct('Min',0,'Max',100,'Units','degrees celsius');



%Define prediction and control horizon and set up the MPC object
p = 96;
m = 8;

Weights = struct('ManipulatedVariables',[10 100 100],'ManipulatedVariablesRate',[0 0 0],...
'OutputVariables',[0 0 0 1000]);

MyMPC = mpc(model,ts,p,m,Weights,InputSpecs,Outputspecs);
setoutdist(MyMPC,'remove',[1 2 3 4]);















